# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from azure.mgmt.core import AsyncARMPipelineClient
from msrest import Serializer, Deserializer

from azure.profiles import KnownProfiles, ProfileDefinition
from azure.profiles.multiapiclient import MultiApiClientMixin
from ._configuration import AzureMachineLearningWorkspacesConfiguration

class _SDKClient(object):
    def __init__(self, *args, **kwargs):
        """This is a fake class to support current implemetation of MultiApiClientMixin."
        Will be removed in final version of multiapi azure-core based client
        """
        pass

class AzureMachineLearningWorkspaces(MultiApiClientMixin, _SDKClient):
    """These APIs allow end users to manage Azure Machine Learning Models, Images, Profiles, and Services.

    This ready contains multiple API versions, to help you deal with all of the Azure clouds
    (Azure Stack, Azure Government, Azure China, etc.).
    By default, it uses the latest API version available on public Azure.
    For production, you should stick to a particular api-version and/or profile.
    The profile sets a mapping between an operation group and its API version.
    The api-version parameter sets the default API version if the operation
    group is not described in the profile.

    :param credential: Credential needed for the client to connect to Azure.
    :type credential: ~azure.core.credentials_async.AsyncTokenCredential
    :param str api_version: API version to use if no profile is provided, or if
     missing in profile.
    :param str base_url: Service URL
    :param profile: A profile definition, from KnownProfiles to dict.
    :type profile: azure.profiles.KnownProfiles
    """

    DEFAULT_API_VERSION = 'v1.0'
    _PROFILE_TAG = "azure.mgmt.machinelearningservices.AzureMachineLearningWorkspaces"
    LATEST_PROFILE = ProfileDefinition({
        _PROFILE_TAG: {
            None: DEFAULT_API_VERSION,
            'artifact': '1.5.0',
        }},
        _PROFILE_TAG + " latest"
    )

    def __init__(
        self,
        credential,  # type: "AsyncTokenCredential"
        api_version=None,
        base_url=None,
        profile=KnownProfiles.default,
        **kwargs  # type: Any
    ) -> None:
        if not base_url:
            base_url = 'https://management.azure.com'
        self._config = AzureMachineLearningWorkspacesConfiguration(credential, **kwargs)
        self._client = AsyncARMPipelineClient(base_url=base_url, config=self._config, **kwargs)
        super(AzureMachineLearningWorkspaces, self).__init__(
            api_version=api_version,
            profile=profile
        )

    @classmethod
    def _models_dict(cls, api_version):
        return {k: v for k, v in cls.models(api_version).__dict__.items() if isinstance(v, type)}

    @classmethod
    def models(cls, api_version=DEFAULT_API_VERSION):
        """Module depends on the API version:

           * 1.5.0: :mod:`artifact.models<azure.mgmt.machinelearningservices.artifact.models>`
           * v1.0: :mod:`mms.models<azure.mgmt.machinelearningservices.mms.models>`
        """
        if api_version == '1.5.0':
            from ..artifact import models
            return models
        elif api_version == 'v1.0':
            from ..mms import models
            return models
        raise ValueError("API version {} is not available".format(api_version))

    @property
    def artifact(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`ArtifactOperations<azure.mgmt.machinelearningservices.artifact.aio.operations.ArtifactOperations>`
        """
        api_version = self._get_api_version('artifact')
        if api_version == '1.5.0':
            from ..artifact.aio.operations import ArtifactOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'artifact'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def assets(self):
        """Instance depends on the API version:

           * v1.0: :class:`AssetsOperations<azure.mgmt.machinelearningservices.mms.aio.operations.AssetsOperations>`
        """
        api_version = self._get_api_version('assets')
        if api_version == 'v1.0':
            from ..mms.aio.operations import AssetsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'assets'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def ml_models(self):
        """Instance depends on the API version:

           * v1.0: :class:`MLModelsOperations<azure.mgmt.machinelearningservices.mms.aio.operations.MLModelsOperations>`
        """
        api_version = self._get_api_version('ml_models')
        if api_version == 'v1.0':
            from ..mms.aio.operations import MLModelsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'ml_models'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def operations(self):
        """Instance depends on the API version:

           * v1.0: :class:`Operations<azure.mgmt.machinelearningservices.mms.aio.operations.Operations>`
        """
        api_version = self._get_api_version('operations')
        if api_version == 'v1.0':
            from ..mms.aio.operations import Operations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'operations'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def profiles(self):
        """Instance depends on the API version:

           * v1.0: :class:`ProfilesOperations<azure.mgmt.machinelearningservices.mms.aio.operations.ProfilesOperations>`
        """
        api_version = self._get_api_version('profiles')
        if api_version == 'v1.0':
            from ..mms.aio.operations import ProfilesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'profiles'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def services(self):
        """Instance depends on the API version:

           * v1.0: :class:`ServicesOperations<azure.mgmt.machinelearningservices.mms.aio.operations.ServicesOperations>`
        """
        api_version = self._get_api_version('services')
        if api_version == 'v1.0':
            from ..mms.aio.operations import ServicesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'services'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    async def close(self):
        await self._client.close()
    async def __aenter__(self):
        await self._client.__aenter__()
        return self
    async def __aexit__(self, *exc_details):
        await self._client.__aexit__(*exc_details)
